## Edit View

Edit glyph outlines, spacing, kerning, mark-positioning, hinting, and more in Edit View.
Edit a glyph by double-clicking it.
Open multiple glyphs in Edit View by selecting them and choosing “View” → “New Tab” (Cmd-T).
In Font View, a selection of glyphs can also be edited by double-clicking the selection or pressing Cmd-Down Arrow.

A Glyphs window can contain multiple Edit View tabs.
Switch to a tab by clicking its tab title.
Press Cmd-Opt-2 through Cmd-Opt-9 to switch to the respective tab.
Cmd-Opt-1 switches to Font View, which is always the first tab in the window.

Switch to the next or previous tab with “View” → “Navigation” → “Show Next Tab” (Ctrl-Tab) or “Show Previous Tab” (Ctrl-Shift-Tab).
Close a tab by moving the mouse cursor over its title and clicking the close  button or choosing “View” → “Close Tab” (Cmd-Shift-W).
Close all tabs except for the current one by holding down the Option key when clicking the close button.
Restore an accidentally closed tab by holding down Option and choosing “View” → “Reopen Last Closed Tab” (Cmd-Opt-Shift-W).

Edit View has two modes: _text mode_ and _edit mode_.

- Use text mode to insert and remove glyphs from Edit View, or adjust the spacing and kerning between glyphs. Choose the Text tool  (shortcut T) to enter text mode. See Entering Text and Spacing & Kerning for more details.

- Enter edit mode by choosing a different tool or by double-clicking a glyph. Or, press the Escape key to edit the glyph located after the text cursor.